@@ -1,4 +1,11 @@
-import matplotlib.pyplot as plt
+# import matplotlib.pyplot as plt
+try:
+    import matplotlib.pyplot as plt
+except ImportError:
+    import os
+    os.system('pip install matplotlib')
+    import matplotlib.pyplot as plt
+
 
 def printData(x_list,y_list):
     print("+-------------------------------+")
